import java.io.File;
import java.io.IOException;
import java.nio.file.FileSystems;
import java.nio.file.StandardWatchEventKinds;
import java.nio.file.WatchEvent;
import java.nio.file.WatchKey;
import java.nio.file.WatchService;
import java.util.List;
import java.util.concurrent.atomic.AtomicBoolean;

public class Watcher {
	private AtomicBoolean stop = new AtomicBoolean(false);
	private WatchService watchService;
	private Thread thread;

	public Watcher(File directory) throws IOException {
		watchService = FileSystems.getDefault().newWatchService();
		directory.toPath().register(watchService, StandardWatchEventKinds.ENTRY_CREATE,
				StandardWatchEventKinds.ENTRY_DELETE, StandardWatchEventKinds.ENTRY_MODIFY,
				StandardWatchEventKinds.OVERFLOW);
	}

	public void stop() {
		stop.set(true);
		if (thread != null) {
			thread.interrupt();
		}
	}

	public void start() {
		this.thread = new Thread() {
			public void run() {
				while (!stop.get()) {
					try {
						WatchKey key = watchService.take();
						List<WatchEvent<?>> events = key.pollEvents();
						for (WatchEvent<?> evt: events) {
							System.out.println(evt);
							Thread.sleep(500);
						}
						key.reset();
					} catch (InterruptedException e) {
						Thread.currentThread().interrupt();
					}
				}
			}
		};
		//thread.setDaemon(true);
		thread.start();
	}
	
	public static void main(String[] args) throws IOException, InterruptedException {
		File dir= new File(args[0]);
		dir.mkdirs();
		File subDir= new File(dir, "subdir");
		Thread.sleep(2000);
		subDir.mkdirs();
		new Watcher(dir).start();
		new Watcher(subDir).start();
	}


}
